import requests
from os import environ
from datetime import datetime, timedelta

from parsing import parse_knmi


class Deployment:

    def __init__(self, base_directory, context):
        """
        Args:
            base_directory (string): The base_directory of the deployment_package.
            context (dict): a dictionary containing details of the deployment that might be useful in your code.

        Required environment variables:
        - API_URL: url to KNMI API

        Optional environment variables:
        - N_DAYS: number of days to collect from the KNMI api
        """

        print("Initialising deployment")

        if 'API_URL' in environ:
            self.api_url = environ['API_URL']
        else:
            self.api_url = ""

        if 'N_DAYS' in environ:
            self.n_days = int(environ['N_DAYS'])
        else:
            self.n_days = 3
        print(f"Initialized with N_DAYS={self.n_days} and API_URL={self.api_url}")

    def request(self, data):
        """
        Args:
            data (dictionary): Request input
                data[end_date] (string): Last collected date. Date format: Y-m-d.
                                         When using an empty string, the last available date is used.

        Returns: dictionary
            [data] (list of strings): Collected temperature data. Each string of format "datetime,temperature"
        """

        print("Processing request")

        if data['end_date'] is None or data['end_date'] == "":
            # The data of two days ago is the latest data that is available by KNMI.
            end_date = datetime.now().date() - timedelta(days=2)
            start_date = end_date - timedelta(days=self.n_days-1)
        else:
            end_date = datetime.strptime(data['end_date'], "%Y-%m-%d").date()
            start_date = end_date - timedelta(days=self.n_days-1)

        print(f"{start_date} - {end_date}")
        start_hour = str(start_date).replace('-', '') + '01'
        end_hour = str(end_date).replace('-', '') + '24'

        # Specify the collected data
        # - By using stns=260, the temperature of location 'De Bilt' is collected
        params = {'start': start_hour,
                  'end': end_hour,
                  'vars': 'TEMP',
                  'stns': '260'}
        r = requests.post(url=self.api_url, data=params)
        r.raise_for_status()
        parsed_data = parse_knmi(r.text)

        print("Finished request")
        return {'data': parsed_data}
